# Example Package

### Description 
A package for stat and data miner,calculate woe and iv,and plot woe ,plot iv,calculate ks ,plot ks and auc,plot roc


This is a simple stat package. You can see more from 
[Gitee](https://gitee.com/py2cn/pyminer).
Or 
[pyminer](http://www.pyminer.com).